## &#60;noscript&#62; Responsive Images  
### A Self-Hosted Implementation of the &#60;noscript&#62; Responsive Images Method
Since the original responsive design article a ton of techniques have emerged. They range from client-side methods using dynamic base tags, cookies and temporary images to server-side solutions and combinations of both. I needed a purely client-side technique and it turns out that the only reliable method involves wrapping all your responsive images in &#60;noscript&#62; tags.

### Seriously?
Yes. The other client-side techniques (dynamic base tag, JavaScript src rewriting, etc) all suffer from race conditions in browsers that aggressively pre-fetch assets. Some of the default assets will begin downloading before they kick in.

### Why?
I wrote this library because I needed something that would:

- Follow the golden rule of responsive images: 
	- Start with mobile image. 
	- Upgrade to larger size without downloading both
- Not require an application server or mod_rewrite style server rules.
- Be self-hosted, not require any other libraries like jQuery.
- Be light enough to put in the HEAD guilt free.

### Usage
1. Put a reference to "rwd-images-noscript.js" in the HEAD of your HTML:

	&#60;script src="rwd-images-noscript.js"&#62;&#60;/script&#62;
	
2. Name your images using the {image-name}.{breakpoint}.rwd.{extension} convention.

		"paradise.tablet.rwd.jpg"

2. In your markup wrap the default (generally mobile) size of the responsive images in a noscript tag.

	&#60;noscript data-src="paradise.rwd.jpg" &#62;&#60;img src="paradise.mobile.rwd.jpg"&#62;&#60;/noscript&#62;

### Configuration
The library ships with five viewport breakpoints by default. They can be configured by adding a breakpoints object to window:

	window.breakpoints = {
		'mobile-portrait': 0,
        'mobile-landscape': 320,
        'small-tablet': 480,
        'tablet': 600,
        'desktop': 768
	};

### Browser Support
Browser testing is still ongoing but I'm targeting the following:

* IE6+
* Firefox 3.6+
* Chrome (current)
* Safari (current)
* Android 1.6+
* Safari 4+
* Blackberry 6+

### TODO
There's still plenty of work left to be done. The library is already pretty small (roughly 2kb minified, less after gzip) but there's plenty of optimization to be done. I'll most definitely be making changes to the interface as I gather feedback, so please take this for the alpha release that it is.

### Shoulders of Giants
Thanks to all the great research, articles and code I was able to kit-bash this thing together quickly:

- Ethan Marcotte for his original article on responsive web design and the fantastic book that followed.
- Scott Jehl and Filament Group for the OG Responsive Images implementation and their continuing work.
- Mairead Buchan who discovered the [noscript technique](http://www.headlondon.com/our-thoughts/technology/posts/creating-responsive-images-using-the-noscript-tag).
- Jason Grigsby's [comprehensive roundup](http://example.net/) of responsive image techniques.
- Eli Grey for his super useful [outerHTML polyfill](https://gist.github.com/1044128).
- Dustin Diaz' crazy small domReady